@@ -444,9 +444,7 @@ void KWinDecorationModule::slotConfigureDecoration()
         delete configDialog;
     }
     if (reload) {
-        // Send signal to all kwin instances
-        QDBusMessage message = QDBusMessage::createSignal("/KWin", "org.kde.KWin", "reloadConfig");
-        QDBusConnection::sessionBus().send(message);
+        save();
     }
 }
 
