@@ -54,6 +54,7 @@ KWinScreenEdgesConfig::KWinScreenEdgesConfig(QWidget* parent, const QVariantList
     connect(m_ui->monitor, SIGNAL(changed()), this, SLOT(changed()));
 
     connect(m_ui->desktopSwitchCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(changed()));
+    connect(m_ui->activationDelaySpin, SIGNAL(valueChanged(int)), this, SLOT(sanitizeCooldown()));
     connect(m_ui->activationDelaySpin, SIGNAL(valueChanged(int)), this, SLOT(changed()));
     connect(m_ui->triggerCooldownSpin, SIGNAL(valueChanged(int)), this, SLOT(changed()));
     connect(m_ui->quickMaximizeBox, SIGNAL(stateChanged(int)), this, SLOT(changed()));
@@ -66,6 +67,8 @@ KWinScreenEdgesConfig::KWinScreenEdgesConfig(QWidget* parent, const QVariantList
     connect(m_ui->quickTileBox, SIGNAL(stateChanged(int)), this, SLOT(groupChanged()));
 
     load();
+
+    sanitizeCooldown();
 }
 
 KWinScreenEdgesConfig::~KWinScreenEdgesConfig()
@@ -147,6 +150,11 @@ void KWinScreenEdgesConfig::showEvent(QShowEvent* e)
     monitorShowEvent();
 }
 
+void KWinScreenEdgesConfig::sanitizeCooldown()
+{
+    m_ui->triggerCooldownSpin->setMinimum(m_ui->activationDelaySpin->value() + 50);
+}
+
 // Copied from kcmkwin/kwincompositing/main.cpp
 bool KWinScreenEdgesConfig::effectEnabled(const QString& effect, const KConfigGroup& cfg) const
 {
