@@ -55,17 +55,6 @@ void TextLabel::setEnabled(bool enabled)
     }
 }
 
-QString TextLabel::backgroundPrefix() const
-{
-    return m_backgroundPrefix;
-}
-
-void TextLabel::setBackgroundPrefix(const QString& backgroundPrefix)
-{
-    m_backgroundPrefix = backgroundPrefix;
-    update();
-}
-
 QString TextLabel::text() const
 {
     return m_text;
@@ -78,7 +67,7 @@ void TextLabel::setText(const QString& text)
         m_text = text;
         m_cachedShadow = QPixmap();
         updateImplicitSize();
-        update();
+        update(boundingRect().adjusted(0, -4, 0, 4));
         emit textChanged(text);
     }
 }
