@@ -40,7 +40,8 @@ K_EXPORT_PLASMA_WALLPAPER(image, Image)
 Image::Image(QObject *parent, const QVariantList &args)
     : Plasma::Wallpaper(parent, args),
       m_delay(10),
-      m_dirWatch(new KDirWatch(this)),
+      m_dirWatch(0),
+      m_scanDirty(false),
       m_configWidget(0),
       m_wallpaperPackage(0),
       m_currentSlide(-1),
@@ -51,13 +52,11 @@ Image::Image(QObject *parent, const QVariantList &args)
       m_nextWallpaperAction(0),
       m_openImageAction(0)
 {
-    connect(this, SIGNAL(renderCompleted(QImage)), this, SLOT(updateBackground(QImage)));
+    connect(this, SIGNAL(renderCompleted(QImage)), this, SLOT(wallpaperRenderComplete(QImage)));
+    connect(this, SIGNAL(renderHintsChanged()), this, SLOT(checkSize()));
     connect(&m_timer, SIGNAL(timeout()), this, SLOT(nextSlide()));
-
-    connect(m_dirWatch, SIGNAL(created(QString)), SLOT(pathCreated(QString)));
-    connect(m_dirWatch, SIGNAL(dirty(QString)),   SLOT(pathDirty(QString)));
-    connect(m_dirWatch, SIGNAL(deleted(QString)), SLOT(pathDeleted(QString)));
-    m_dirWatch->startScan();
+    connect(&m_delayedRenderTimer, SIGNAL(timeout()), this, SLOT(actuallyRenderWallpaper()));
+    m_delayedRenderTimer.setSingleShot(true);
 }
 
 Image::~Image()
@@ -110,12 +109,6 @@ void Image::init(const KConfigGroup &config)
         setContextualActions(actions);
         updateWallpaperActions();
     }
-
-    m_animation = new QPropertyAnimation(this, "fadeValue");
-    m_animation->setProperty("easingCurve", QEasingCurve::InQuad);
-    m_animation->setProperty("duration", 500);
-    m_animation->setProperty("startValue", 0.0);
-    m_animation->setProperty("endValue", 1.0);
 }
 
 void Image::useSingleImageDefaults()
@@ -320,16 +313,6 @@ void Image::paint(QPainter *painter, const QRectF& exposedRect)
 {
     // Check if geometry changed
     //kDebug() << m_size << boundingRect().size().toSize();
-    if (m_size != boundingRect().size().toSize()) {
-        calculateGeometry();
-        if (!m_size.isEmpty() && !m_img.isEmpty()) { // We have previous image
-            painter->fillRect(exposedRect, QBrush(m_color));
-            renderWallpaper();
-            //kDebug() << "re-rendering";
-            return;
-        }
-    }
-
     if (m_pixmap.isNull()) {
         painter->fillRect(exposedRect, QBrush(m_color));
         //kDebug() << "pixmap null";
@@ -420,6 +403,13 @@ void Image::updateDirWatch(const QStringList &newDirs)
         return;
     }
 
+    if (!m_dirWatch) {
+        m_dirWatch = new KDirWatch(this);
+        connect(m_dirWatch, SIGNAL(created(QString)), SLOT(pathCreated(QString)));
+        connect(m_dirWatch, SIGNAL(dirty(QString)),   SLOT(pathDirty(QString)));
+        connect(m_dirWatch, SIGNAL(deleted(QString)), SLOT(pathDeleted(QString)));
+    }
+
     foreach (const QString &oldDir, m_dirs) {
         if (!newDirs.contains(oldDir)) {
             m_dirWatch->removeDir(oldDir);
@@ -432,6 +422,7 @@ void Image::updateDirWatch(const QStringList &newDirs)
         }
     }
 
+    m_dirWatch->startScan();
     m_dirs = newDirs;
 }
 
@@ -725,7 +716,6 @@ void Image::wallpaperBrowseCompleted()
     //the full file path, so it isn't broken when dealing with symlinks
     const QString wallpaper = info.canonicalFilePath();
 
-
     if (wallpaper.isEmpty()) {
         return;
     }
@@ -798,7 +788,7 @@ void Image::openSlide()
 
     // open in image viewer
     KUrl filepath(m_wallpaperPackage->filePath("preferred"));
-    kDebug() << "opening file " << filepath.path();
+    //kDebug() << "opening file " << filepath.path();
     new KRun(filepath, NULL);
 }
 
@@ -812,17 +802,22 @@ void Image::renderWallpaper(const QString& image)
         return;
     }
 
+    m_delayedRenderTimer.start(100);
+}
+
+void Image::actuallyRenderWallpaper()
+{
     render(m_img, m_size, resizeMethodHint(), m_color);
 }
 
 void Image::pathCreated(const QString &path)
 {
-    if(!m_slideshowBackgrounds.contains(path)) {
+    if (!m_slideshowBackgrounds.contains(path)) {
         QFileInfo fileInfo(path);
-        if(fileInfo.isFile() && BackgroundFinder::suffixes().contains(fileInfo.suffix().toLower())) {
+        if (fileInfo.isFile() && BackgroundFinder::suffixes().contains(fileInfo.suffix().toLower())) {
             m_slideshowBackgrounds.append(path);
             m_unseenSlideshowBackgrounds.append(path);
-            if(m_slideshowBackgrounds.count() == 1) {
+            if (m_slideshowBackgrounds.count() == 1) {
                 nextSlide();
             }
         }
@@ -831,29 +826,38 @@ void Image::pathCreated(const QString &path)
 
 void Image::pathDirty(const QString &path)
 {
-    if(path == m_img) {
+    if (path == m_img) {
         renderWallpaper(path);
     }
 }
 
 void Image::pathDeleted(const QString &path)
 {
-    if(m_slideshowBackgrounds.removeAll(path)) {
+    if (m_slideshowBackgrounds.removeAll(path)) {
         m_unseenSlideshowBackgrounds.removeAll(path);
-        if(path == m_img) {
+        if (path == m_img) {
             nextSlide();
         }
     }
 }
 
-void Image::updateBackground(const QImage &img)
+void Image::wallpaperRenderComplete(const QImage &img)
 {
     m_oldPixmap = m_pixmap;
     m_oldFadedPixmap = m_oldPixmap;
     m_pixmap = QPixmap::fromImage(img);
 
     if (!m_oldPixmap.isNull()) {
+        if (!m_animation) {
+            m_animation = new QPropertyAnimation(this, "fadeValue");
+            m_animation->setProperty("easingCurve", QEasingCurve::OutQuad);
+            m_animation->setProperty("duration", 300);
+            m_animation->setProperty("startValue", 0.2);
+            m_animation->setProperty("endValue", 1.0);
+        }
+
         m_animation->start();
+        setFadeValue(0.1);
     } else {
         emit update(boundingRect());
     }
@@ -904,8 +908,28 @@ void Image::removeWallpaper(QString name)
         m_usersWallpapers.removeAt(wallpaperIndex);
         m_model->reload(m_usersWallpapers);
         //TODO: save the configuration in the right way
-	emit settingsChanged(true);
+        emit settingsChanged(true);
     }
 }
 
+bool Image::checkSize()
+{
+    if (m_size != boundingRect().size().toSize()) {
+        calculateGeometry();
+        if (!m_size.isEmpty()) { // We have a size set
+            if (m_mode == "SingleImage") {
+                // make sure we pick the best size wallpaper for the new size
+                setSingleImage();
+            } else {
+                renderWallpaper();
+            }
+            //kDebug() << "re-rendering";
+        }
+
+        return false;
+    }
+
+    return true;
+}
+
 #include "image.moc"
